@@ -80,6 +80,8 @@ try:
     timeoutsocket.setDefaultSocketTimeout(10)
 except ImportError:
     pass
+import logging
+log = logging.getLogger("Griffith")
 
 LICENSE_KEY = ""
 ASSOCIATE = "webservices-20"
@@ -204,7 +206,7 @@ def unmarshal(element):
                 if type(getattr(rc, key)) <> type([]):
                     setattr(rc, key, [getattr(rc, key)])
                 setattr(rc, key, getattr(rc, key) + [unmarshal(child)])
-            elif isinstance(child, minidom.Element) and (child.tagName == 'Details'):
+            elif isinstance(child, minidom.Element) and (child.tagName == 'Details' or child.tagName == 'Item'):
                 # make the first Details element a key
                 setattr(rc,key,[unmarshal(child)])
                 #dbg: because otherwise 'hasattr' only tests
@@ -224,6 +226,8 @@ def unmarshal(element):
 
 def buildURL(search_type, searchfield, searchvalue, product_line, type, page, license_key, locale, associate):
     _checkLocaleSupported(locale)
+    if isinstance(searchvalue, unicode):
+        searchvalue = searchvalue.encode('utf-8') # needed for urllib.quote
     url = "http://" + _supportedLocales[locale][1]
     if search_type == 'ItemLookup':
         url += "&AssociateTag=%s" % associate
@@ -247,6 +251,7 @@ def buildURL(search_type, searchfield, searchvalue, product_line, type, page, li
         url += "&Sort=titlerank"
     if not APIVERSION is None:
         url += "&Version=%s" % APIVERSION
+    log.info('URL: ' + url)
     return url
 
 
