@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportPDF.py 1040 2008-11-15 21:13:49Z mikej06 $'
+__revision__ = '$Id: PluginExportPDF.py 1122 2009-01-16 20:58:58Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -31,41 +31,39 @@ from reportlab.rl_config import defaultEncoding
 from reportlab.platypus import Image, SimpleDocTemplate, Paragraph, Spacer
 from reportlab.lib.styles import getSampleStyleSheet
 from xml.sax import saxutils
-import os, gtk
-import version
-import gutils
+import config
+import gtk
+import os
 import string
 import sys
-import config
 from locale import getdefaultlocale
-from sqlalchemy import Select, desc
+import db
+import gutils
+import version
+from plugins.export import Base
 
-exec_location = os.path.abspath(os.path.dirname(sys.argv[0]))
+class ExportPlugin(Base):
+    name = "PDF"
+    description = _("PDF export plugin")
+    author = "Vasco Nunes"
+    email = "<vasco.m.nunes@gmail.com>"
+    version = "0.5"
+    
+    fields_to_export = ('number', 'o_title', 'title', 'director', 'genre', 'cast')
 
-plugin_name = "PDF"
-plugin_description = _("PDF export plugin")
-plugin_author = "Vasco Nunes"
-plugin_author_email = "<vasco.m.nunes@gmail.com>"
-plugin_version = "0.4"
-
-class ExportPlugin:
-    def __init__(self, database, locations, parent_window, debug, **kwargs):
-        self.db = database
-        self.locations = locations
-        self.parent = parent_window
-        self.config = kwargs['config']
+    def initialize(self):
         self.styles = getSampleStyleSheet()
-        self.export_simple_pdf()
-        self.fontName = ""
+        self.fontName = ''
+        return True
 
-    def export_simple_pdf(self):
+    def run(self):
         """exports a simple movie list to a pdf file"""
         
         if self.config.get('font', '') != '':
-                self.fontName = 'custom_font'
-                pdfmetrics.registerFont(TTFont(self.fontName, self.config.get('font', '')))
+            self.fontName = 'custom_font'
+            pdfmetrics.registerFont(TTFont(self.fontName, self.config.get('font', '')))
         else:
-                self.fontName = "Helvetica"
+            self.fontName = "Helvetica"
 
         basedir = None
         if not self.config is None:
@@ -81,7 +79,7 @@ class ExportPlugin:
             overwrite = None
             pdffilename = filename[0].decode('utf-8')
             if os.path.isfile(pdffilename):
-                response = gutils.question(self,_("File exists. Do you want to overwrite it?"),1,self.parent)
+                response = gutils.question(_("File exists. Do you want to overwrite it?"), True, self.parent_window)
                 if response==-8:
                     overwrite = True
                 else:
@@ -100,40 +98,50 @@ class ExportPlugin:
                 defaultEnc = 'utf-8'
                 style = self.styles["Normal"]
                 Story = [Spacer(1,2*inch)]
-                # define some custom stylesheetfont
-                total = self.db.Movie.count()
-                p = Paragraph("<font name='" + self.fontName +"' size=\"18\">" + saxutils.escape((_("List of films")).encode('utf-8')) + '</font>', self.styles["Heading1"] )
-                Story.append(p)
-                Story.append(Paragraph(" ",style))
-                p = Paragraph("<font name='" + self.fontName +"' size=\"10\">" + saxutils.escape((_("Total Movies: %s") % str(total)).encode('utf-8'))  + '</font>', self.styles["Heading3"])
-                Story.append(p)
-                Story.append(Paragraph(" ",style))
-                movies = Select(self.db.Movie.c)
-                # select sort column
+
+                # select sort column - FIXME
                 sort_column_name = self.config.get('sortby', 'number', section='mainlist')
                 sort_reverse = self.config.get('sortby_reverse', False, section='mainlist')
                 do_grouping = True
                 for i in sort_column_name.split(','):
                     if i != 'title' and i != 'o_title':
                         do_grouping = False
-                    if self.db.Movie.c.has_key(i):
-                        if sort_reverse:
-                            movies.order_by_clause.append(desc(self.db.Movie.c[i]))
-                        else:
-                            movies.order_by_clause.append(self.db.Movie.c[i])
-                movies = movies.execute().fetchall()
-                first_letter = '0'
+
+                # build the query
+                query = self.get_query()
+                movies = query.execute().fetchall()
+
+                # define some custom stylesheetfont
+                total = len(movies)
+                p = Paragraph("<font name='" + self.fontName +"' size=\"18\">" + saxutils.escape((_("List of films")).encode('utf-8')) + '</font>', self.styles["Heading1"] )
+                Story.append(p)
+                Story.append(Paragraph(" ",style))
+                p = Paragraph("<font name='" + self.fontName +"' size=\"10\">" + saxutils.escape((_("Total Movies: %s") % str(total)).encode('utf-8'))  + '</font>', self.styles["Heading3"])
+                Story.append(p)
+                Story.append(Paragraph(" ",style))
+                # output movies
+                first_letter = ''
                 for movie in movies:
                     number = movie.number
-                    original_title = str(movie.o_title).encode(defaultEnc)
-                    title = str(movie.title).encode(defaultEnc)
+                    if movie.o_title:
+                        original_title = movie.o_title.encode(defaultEnc)
+                    else:
+                        original_title = ''
+                    if movie.title:
+                        title = movie.title.encode(defaultEnc)
+                    else:
+                        title = ''
+                    grouping_title = movie.title
+                    if grouping_title is None:
+                        grouping_title = u'None'
                     if movie.director:
-                        director = ' - ' + str(movie.director).encode(defaultEnc)
+                        director = ' - ' + movie.director.encode(defaultEnc)
                     else:
                         director = ""
                     # group by first letter
-                    if do_grouping and title[0] != first_letter:
-                        if title[0] in '0123456789':
+                    # use movie.title/grouping_title for grouping because of encoding problems !!!
+                    if do_grouping and grouping_title[0] != first_letter:
+                        if grouping_title[0] in '0123456789':
                             # Group Numbers
                             if first_letter != '0-9':
                                 first_letter = '0-9'
@@ -141,7 +149,7 @@ class ExportPlugin:
                                 p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Heading2'])
                                 Story.append(p)
                         else:
-                            first_letter = title[0]
+                            first_letter = grouping_title[0]
                             paragraph_text = '<font name=' + self.fontName + ' size="15">' + saxutils.escape(first_letter) + '</fonts>'
                             p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Heading2'])
                             Story.append(p)
@@ -152,20 +160,20 @@ class ExportPlugin:
                         '</font>'
                     p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Normal'])
                     Story.append(p)
-                    if not movie.genre is None:
+                    if movie.genre is not None:
                         paragraph_text = '<font name=' + self.fontName + ' size="5">' + \
-                        '<b>' + _('Genre') + ': </b>' + saxutils.escape(str(movie.genre).encode(defaultEnc)) + \
+                        '<b>' + _('Genre') + ': </b>' + saxutils.escape(movie.genre.encode(defaultEnc)) + \
                         '</font>'
                         p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Normal'])
                         Story.append(p)
-                    if not movie.cast is None:
+                    if movie.cast is not None:
                         paragraph_text = '<i><font name=' + self.fontName + ' size="5">' + \
-                        '<b>' + _('Cast') + ': </b>' + saxutils.escape('; '.join(str(movie.cast).encode(defaultEnc).split("\n")[0:2])) + \
+                        '<b>' + _('Cast') + ': </b>' + saxutils.escape('; '.join(movie.cast.encode(defaultEnc).split("\n")[0:2])) + \
                             '</font></i>'
                         p = Paragraph(paragraph_text.decode(defaultEnc), self.styles['Normal'])
                         Story.append(p)
                 c.build(Story, onFirstPage=self.page_template, onLaterPages=self.page_template)
-                gutils.info(self, _('PDF has been created.'), self.parent)
+                gutils.info(_('PDF has been created.'), self.parent_window)
             
     def page_template(self, canvas, doc):
         canvas.saveState()
